#
# spec file for package apcupsd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           apcupsd
Version:        3.14.14
Release:        lp150.118.4
Summary:        APC UPS Daemon (Powerful Daemon for APC UPSs)
License:        GPL-2.0-only
Group:          Hardware/UPS
Url:            http://www.apcupsd.com/
Source:         https://sourceforge.net/projects/apcupsd/files/apcupsd%%20-%%20Stable/%{version}/apcupsd-%{version}.tar.gz
Source2:        README.SUSE
Source4:        %{name}.hibernate
Source5:        %{name}.sysconfig
Source6:        %{name}.logrotate
Source7:        apcupsd-httpd.conf
Source8:        https://sourceforge.net/projects/apcupsd/files/apcupsd%%20-%%20Stable/%{version}/apcupsd-%{version}.tar.gz.sig
Source9:        %{name}.keyring
Source10:       %{name}.firewall
# PATCH-FIX-OPENSUSE apcupsd-suse.patch sbrabec@suse.cz -- Do not perform halt script alternation on install.
Patch0:         apcupsd-suse.patch
# PATCH-FEATURE-OPENSUSE apcupsd-hibernate.patch sbrabec@suse.cz -- Support for hibernation on powerfail.
Patch2:         apcupsd-hibernate.patch
# PATCH-FIX-OPENSUSE apcupsd-3.14.8-systemd.patch p.drouand@gmail.com -- systemd support
Patch11:        apcupsd-3.14.8-systemd.patch
# PATCH-FIX-OPENSUSE apcupsd-3.14.9-fixgui.patch rhbz#578276 p.drouand@gmail.com -- fix crash in gui
Patch13:        apcupsd-3.14.9-fixgui.patch
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  distribution-release
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libusb-devel
BuildRequires:  mailx
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  systemd-sysvinit
BuildRequires:  tcpd-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(gnome-vfs-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(x11)
Requires:       mailx
Requires(post): %fillup_prereq
Requires(post): grep
Requires(post): sed
Recommends:     logrotate
%{?systemd_requires}

%description
Controls and monitors the status of an APC UPS under Linux. Allows your
computer or server to run for a specified length of time on UPS power
then executes a controlled shutdown in the case of an extended power
failure. Find APC on the Internet at http://www.apc.com/.

APC also made their PowerChute plus available for download at
http://www.apc.com/tools/download/.

%package cgi
Summary:        Web interface for apcupsd
Group:          Hardware/UPS
Requires:       %{name} = %{version}

%description cgi
A CGI interface to the APC UPS monitoring daemon.

%package gui
Summary:        APC UPS Monitor GUI (for APC UPSs)
Group:          Hardware/UPS
Requires:       %{name} = %{version}

%description gui
Controls and monitors the status of an APC UPS under Linux. Allows your
computer or server to run for a specified length of time on UPS power
then executes a controlled shutdown in the case of an extended power
failure. Find APC on the Internet at http://www.apc.com/.

APC also made their PowerChute plus available for download at
http://www.apc.com/tools/download/.

%prep
%setup -q
cp -a %{SOURCE2} %{SOURCE4} .
%patch0
%patch2
%patch11 -p1
%patch13 -p1

%build
%configure \
	--sysconfdir=%{_sysconfdir}/%{name} \
	--with-libwrap \
	--enable-all \
	--with-lock-dir=%{_localstatedir}/lock \
	--with-cgi-bin=%{apache_datadir}/cgi-bin \
	--with-distname=$(grep ID_LIKE %{_sysconfdir}/os-release | cut -d = -f 2 | tr -d '"')
make %{?_smp_mflags}

%install
%make_install
install -m744 platforms/apccontrol \
              %{buildroot}%{_sysconfdir}/%{name}/apccontrol
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}
%suse_update_desktop_file gapcmon
chmod 644 %{buildroot}/%{_datadir}/pixmaps/*.png
# Cleanup for later doc macro processing
chmod -x examples/*.c
rm examples/*.in
find examples users_guide -type f | xargs chmod 644
# fix end-of-line encoding
dos2unix -o examples/status/SmartUPS-vs-650.status examples/snoopdecode.c examples/rpt/Smart-UPS-1500.rpt \
	examples/rpt/Back-UPS-ES-550.rpt examples/rpt/Back-UPS-CS-650.rpt examples/rpt/Back-UPS-BR-800.rpt
# hid-ups.rpt is duplicate by BackUPS.rpt
%fdupes -s examples/rpt/

rm -r %{buildroot}/%{_datadir}/hal
mkdir -p %{buildroot}%{_libexecdir}/systemd/system-sleep
sed "s:@PWRFAILDIR@:%{_sysconfdir}/%{name}:g" <%{name}.hibernate >%{buildroot}%{_libexecdir}/systemd/system-sleep/apcupsd.sh
chmod +x %{buildroot}%{_libexecdir}/systemd/system-sleep/apcupsd.sh

mkdir -p %{buildroot}%{_fillupdir}
cp %{SOURCE5} %{buildroot}%{_fillupdir}/sysconfig.%{name}

# systemd support and remove initd support for opensuse 12.2 and higher
install -p -D -m644 %{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -p -D -m755 %{name}_shutdown %{buildroot}%{_libexecdir}/systemd/system-shutdown/%{name}_shutdown
rm %{buildroot}%{_initddir}/%{name}

install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -m0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -d %{buildroot}%{_sysconfdir}/apache2/conf.d/
install -m0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/apache2/conf.d/%{name}.conf

# firewall config
install -m 644 -D %{SOURCE10} %{buildroot}/%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}

%pre
%service_add_pre %{name}.service

%post
%fillup_only
%service_add_post %{name}.service
# Remove HALT_POWERDOWN_INSERT, it is not needed with systemd (it was last time filled in 13.1).
# We need to handle only the last form, which was already used in SLE11.
if test -f etc/sysconfig/shutdown ; then
  if usr/bin/grep -q '^HALT_POWERDOWN_INSERT=' etc/sysconfig/shutdown ; then
    if ! usr/bin/grep -q '^HALT_POWERDOWN_INSERT=""' etc/sysconfig/shutdown ; then
      if usr/bin/grep -q '^HALT_POWERDOWN_INSERT="%{_sysconfdir}/init\.d/apcupsd try-powerdown"' etc/sysconfig/shutdown ; then
        usr/bin/sed -i 's:^\(HALT_POWERDOWN_INSERT="\)%{_sysconfdir}/init\.d/apcupsd try-powerdown":\1":' etc/sysconfig/shutdown
      else
        echo >&2 "apcupsd: WARNING: Unknown value of HALT_POWERDOWN_INSERT in %{_sysconfdir}/sysconfig/shutdown."
        echo >&2 "         Keeping unchanged. If it still exists, it should be:"
        echo >&2 "HALT_POWERDOWN_INSERT=\"\""
      fi
    fi
  fi
fi
# User installed file, by default in docdir. Not needed any more, and will never be.
rm -f etc/init.d/apcupsd-early-powerdown

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%license COPYING
%doc ChangeLog examples ReleaseNotes README.SUSE
%{_sbindir}/%{name}
%{_sbindir}/apcaccess
%{_sbindir}/apctest
%{_sbindir}/smtp
%{_sbindir}/rc%{name}
%{_unitdir}/%{name}.service
%{_libexecdir}/systemd/system-shutdown/%{name}_shutdown
%{_libexecdir}/systemd/system-sleep/%{name}.sh
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/changeme
%config(noreplace) %{_sysconfdir}/%{name}/commfailure
%config(noreplace) %{_sysconfdir}/%{name}/commok
%config(noreplace) %{_sysconfdir}/%{name}/onbattery
%config(noreplace) %{_sysconfdir}/%{name}/offbattery
%config(noreplace) %{_sysconfdir}/logrotate.d/apcupsd
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}
%attr(0755,root,root) %{_sysconfdir}/%{name}/apccontrol
%{_mandir}/man?/*.*
%{_fillupdir}/sysconfig.%{name}

%files gui
%{_bindir}/gapcmon
%{_datadir}/applications/gapcmon.desktop
%{_datadir}/pixmaps/*.png

%files cgi
%config(noreplace) %{_sysconfdir}/apache2/conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.css
%config(noreplace) %{_sysconfdir}/%{name}/hosts.conf
%config(noreplace) %{_sysconfdir}/%{name}/multimon.conf
%{apache_datadir}/cgi-bin/multimon.cgi
%{apache_datadir}/cgi-bin/upsfstats.cgi
%{apache_datadir}/cgi-bin/upsstats.cgi
%{apache_datadir}/cgi-bin/upsimage.cgi

%changelog
* Wed Mar 21 2018 tchvatal@suse.com
- Do not use path based dependency but use normal package name
* Thu Mar 15 2018 tchvatal@suse.com
- Drop support for < sle12, also removes patch:
  * apcupsd-pm-utils.patch
- Drop intitscript
- Format with spec-cleaner
- Use license macros instead of %%doc macros
* Mon Dec 11 2017 crrodriguez@opensuse.org
- BuildRequire pkgconfig(x11) not xorg-x11-devel
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Aug 31 2017 dimstar@opensuse.org
- Pass --with-distname=, based on the values of ID_LIKE from
  /etc/os-release to configure. Since the removal of
  /etc/SuSE-release, the build system is no longer able to identify
  us building on a SUSE system. Let's help it.
* Thu Dec  8 2016 manfred99@gmx.ch
- update apcupsd-httpd.conf to work with apache2 >= 2.4. Entries
  are commented out, so this file acts as example only. bsc#950950
* Tue May 31 2016 manfred99@gmx.ch
- Update to apcupsd version 3.14.14
  * win32: Fix missing DLLs when installing only apctray
  * Fixes for socket error handling. Resolves apcaccess crash when connection
    fails as well as several other theoretical issues.
  * MODBUS/USB error handling (COMMLOST) improvements for faulty USB links
  * Fix hiddev binding when usbfs is mounted on /dev/bus/usb instead of
    /proc/bus/usb. This is necessary for switching between MODBUS/USB and
    USB/HID on Linux.
  * Update GPLv2 text and FSF address to match current versions from FSF.
  * Various fixes for potential issues suggested by Coverity Scan
  * MacOS X port support for El Capitan System Integrity Protection (SIP)
    aka "rootless"
  * Fix shutdown failure on Windows when UPSNAME includes spaces
  * Fix building bsd-usb driver
    (This was broken when modbus-usb support was added.)
  * Add status display for output current as well as apparent power
- fix firewall rule installation in spec file
- drop BuildRequires: net-snmp-devel, net-snmp was dropped in favour of snmplite
- drop installation of own automake files for ppc64, not needed any more
- Removed patches, fixed in upstream:
  * apcupsd-3.14.6-undef-MIB-for-new-net-snmp.diff
  * fix-fsf-adress.patch
  * apcupsd-3.14.1-cloexec.patch
  * apcupsd-gpp.patch
- Removed patch, not needed as it builds on all supported arches,
  and not linking against libstdc++ is done on purpose:
  * apcupsd-3.14.8-cxxld.patch
* Mon Jul 13 2015 tchvatal@suse.com
- Ensure locfile is properly set bnc#929444
* Sat Apr 18 2015 matwey.kornilov@gmail.com
- Move *.cgi scripts to apcupsd-cgi package (fix boo#925886)
* Thu Apr  2 2015 tchvatal@suse.com
- Version bump to 3.14.13:
  * apcaccess and apcupsd status format updates to ease parsing by scripts
  * UPS name is included in subject line of emails in default scripts
  * Default event scripts pull SYSADMIN and APCUPSD_MAIL definitions from a
    common config file so they can easily be configured in one place
  * MODBUS USB support
    Previous releases supported MODBUS serial (RS232). This release adds
    support for MODBUS over USB. This protocol is preferable to the normal
    USB HID driver because it offers access to more UPS data readouts and
    controls. The only configuration file change needed versus MODBUS serial
    is to change UPSCABLE to usb and use an empty DEVICE setting. See the
    MODBUS section of the apcupsd manual for more details.
  * Support for Apple Notification Center on Mac OS X (replaces Growl)
  * Apple install packages and binaries are signed with an Apple Developer
    key for compatibility with Gate Keeper
  * Windows USB driver has been updated with additional USB identifiers to
    support future APC products.
  * Fix issue with certain Back-UPS USB models repeatedly cycling power on/off
    after killpower is issued
  * Fix display of battery level during MODBUS calibration
  * Fix apctest EEPROM setting on various models
  * Close and reopen serial port during extended COMMLOST in apcsmart driver
    (helps recover connection when USB serial port dongles are reconnected)
  * Avoid probing non-APC USB devices as it can cause lockups
  * Fix issue with service failing to start on Windows during boot with USB UPS
  * Fix bogus lock file error when config file error forces early termination
  * Fix MODBUS NOMOUTV reading for voltages other than 120VAC
  * Fix LOADPCT (CI_LOAD) on MODBUS driver
  * Fix issue with net driver not reporting MODEL value
  * Fix several potential issues identified by Coverity static analysis
  * Numerous other fixes and improvements all over the code, many of them
    submitted by users...Thank you!
- Refreshed patches:
  * apcupsd-3.14.1-cloexec.patch
  * apcupsd-3.14.8-cxxld.patch
  * apcupsd-gpp.patch
- Removed patch:
  * apcupsd-3.14.10-nodbg.patch
* Thu Apr  2 2015 tchvatal@suse.com
- Cleanup with spec-cleaner
- Remove patch that is never applied today:
  * apcupsd-powersave.patch
* Tue Dec  2 2014 sbrabec@suse.cz
- Fix removal of HALT_POWERDOWN_INSERT (bsc#907702).
* Sun Nov 16 2014 matwey.kornilov@gmail.com
- Add patch apcupsd-3.14.10-nodbg.patch: reduce amount of debug
  messages (redhat #1053324)
* Sun Nov 16 2014 matwey.kornilov@gmail.com
- fix HIBERNATE variable initialization in apccontrol script
* Tue Aug 19 2014 wagner-thomas@gmx.at
- added config for SuSEfirewall2
* Wed May 14 2014 meissner@suse.com
- %%service_add_pre in  %%pre section missing, added.
* Fri Feb 14 2014 sbrabec@suse.cz
- Replace pm-utils support by systemd (FATE#316824).
  add: apcupsd-pm-utils.patch (for old products only)
  replace: apcupsd.hibernate
  update: apcupsd-hibernate.patch, README.SUSE
- Fix init script references to apcupsd-lite.
  update: apcupsd.init
* Wed Feb 12 2014 sbrabec@suse.cz
- Updated to version 3.14.11:
  * APC MODBUS protocol support over RS232
    For more see ReleaseNotes.
- Verify GPG signature.
- Remove obsolete apcupsd-early-powerdown script.
- Remove upgrade scripts for SuSE Linux 8 and SLES 8.
- Do not call powersave-notify (regression bnc#856907).
* Thu Jan  9 2014 p.drouand@gmail.com
- Add %%fillup_prereq PreReq tag and %%{fillup_only} in %%post to
  correctly fillup sysconfig file; fix bnc#837337
* Sun Mar 10 2013 dimstar@opensuse.org
- Update apcupsd-3.14.8-systemd.patch: apcupsd lives in /usr/sbin,
  not in /sbin (bnc#801312).
* Fri Jan 11 2013 cfarrell@suse.com
- license update: GPL-2.0
* Fri Jan 11 2013 aj@suse.de
- Remove patch apcupsd-largebuf-overflow.patch, it's upstream now
* Fri Jan 11 2013 coolo@suse.com
- fix build on factory - systemd moved to /usr
* Fri Sep 14 2012 p.drouand@gmail.com
- Updated to version 3.14.10:
  * Fix missing status and spurrious incorrect status on newer BackUPS CS
    models using USB interface.
  * USB compatibility fixes for Mac OS X Lion
  * USB driver support for newer Microlink models on Mac OS X Lion and Windows
  * Ignore transitions to battery due to calibration (possible if user
    initiates calibration, then exits apctest and starts apcupsd before
    calibration completes.
  * Fix truncation of long UPS model names such as "Smart-UPS RT 5000 XL"
  * Fix MODEL vs. APCMODEL confusion. Remove APCMODEL and rename old MODEL
    aka 'mode' to DRIVER.
- Improve Systemd and logrotate support
- Remove apcupsd-lite support : difference between apcupsd-lite and
  apcupsd are minimal or cpu consumption don't justify his presence
* Tue May 29 2012 jengelh@inai.de
- Adjust directory name to source config.guess/sub from
  to be a /little/ more future proof.
* Thu Mar  1 2012 aj@suse.de
- Buildrequire xorg-x11-devel
* Wed Feb  8 2012 dvaleev@suse.com
- fix ppc64 build
* Tue Jan 31 2012 sbrabec@suse.cz
- Mark all files in /etc/apcupsd as config files. Their editing
  sometimes makes sense (bnc#744358).
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Mon Oct 17 2011 mkubecek@suse.cz
- apcupsd-3.14.8-exit-race.patch:
  When terminating apcupsd, cancel other threads before cleanup to
  avoid race condition and possible segfault (bnc#724487).
- Change build requirement from sysvinit to sysvinit-init for 12.1
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Thu Aug 25 2011 sbrabec@suse.cz
- Implemented hibernate on power fail (bnc#703592#c39).
* Tue Aug  2 2011 sbrabec@suse.cz
- Fixed init check to succeed with unmounted /usr (bnc#703592#c23).
* Mon Jul  4 2011 sbrabec@suse.cz
- Updated to version 3.14.8:
  * Implement battery calibration and self-test interval in apctest
    for USB models.
  * Add support for turning the UPS off completely.
  * Updates of SNMP code.
  * Add support for reading battery voltage from the PowerSummary.
  * Switch time/date output format to simplified ISO.
  * Compilation warning fixes.
  * Other bug fixes and improvements.
  * Documentation improvements.
- Removed HAL support.
* Thu Mar 24 2011 vcizek@novell.com
- fixed apcupsd-lite path in init script
  (reported later as bnc#703592)
* Tue Jul 27 2010 cristian.rodriguez@opensuse.org
- avoid leaking file descriptors (use CLOEXEC, patch from Fedora)
* Wed Mar 31 2010 coolo@novell.com
- package requires sysvinit to build
* Mon Feb 15 2010 seife@opensuse.org
- add missing hal directories to pass rpmlint checks
* Mon Feb 15 2010 seife@opensuse.org
- fix build with newer net-snmp by undefining MIB
* Fri Oct 30 2009 sbrabec@suse.cz
- Require distribution-release, not dummy-release (bnc#550230).
* Mon Jun 29 2009 sbrabec@suse.cz
- Updated to version 3.14.6:
  * Major updates to the User Manual.
  * New manpages for apcupsd, apcupsd.conf, apctest, apcaccess, and
    apccontrol.
  * Add support for turning the UPS off completely.
  * apcsmart: Deadlock fixes during comms failures.
  * linux-usb: Fix out-of-bounds array access.
  * Fix build with gcc-4.4.
  * apcsmart: Fix crash during process shutdown (SIGTERM).
  * Several other minor fixes and improvements.
* Tue Jun  2 2009 crrodriguez@suse.de
- fix build
* Wed Feb 25 2009 ro@suse.de
- run suse_update_config in autoconf directory to fix build
  on ppc64
* Wed Jan 28 2009 sbrabec@suse.cz
- Updated to version 3.14.5:
  * docs: Document the /refresh switch for apctray.
  * apctest: Do not create pid file.
  * gapcmon: Network connect timeout fix.
  * Fix a few unsafe uses of sprintf and strcat.
  * gapcmon: Iconify fixes for KDE
  * Fix LOWBATT glitch handling bug.
  * Support shutting down apcupsd instances running in other
    sessions.
  * docs: PCNET username and password details.
* Fri Sep 19 2008 ro@suse.de
- buildreq dummy-release instead of openSUSE-release
* Mon Jul 14 2008 sbrabec@suse.cz
- Updated to version 3.14.4:
  * Build system rewrite.
  * Built-in version of libgd for multimon cgi has been removed
  * Removal of NLS support.
  * Powerflute has been disabled.
  * gapcmon: Corrected the use of NOMPOWER and the calc of current
    usage amount.
  * Add a heuristic to fix up incorrect NOMINV or NOMOUTV.
  * Fix hal policy file syntax.
  * A HAL policy file is automatically installed on Linux systems
    to disable the hald-addon-hid-ups module which conflicts with
    apcupsd's control of USB UPSes.
  * Add support for Nominal Power.
  * Add units to NOMINV, NOMOUTV, and NOMBATTV stats.
  * Eliminate warnings emitted from gcc-4.2.1.
  * Fix killpower and eeprom settings bug on USB models introduced
    when INPUT reports were prioritized over FEATURE reports.
  * Fix bugs that could cause NIS-net driver to get stuck waiting
    for comms to be restored instead of shutting down.
- Fixed UPS shutdown on systems with /usr on a different file
  system (bnc#407269).
* Wed Feb 20 2008 jdelvare@suse.de
- Remove duplicate index.html file in documentation, create a
  symbolic link instead to save some disk space.
- Fix rpmlint warnings about bad end-of-line encoding of some
  documentation files.
* Mon Feb 18 2008 jdelvare@suse.de
- Package apctest.8 properly.
- Convert the user's guide to HTML before packaging it. Not that
  many users know what to do with latex source files (361885).
- Do not package the uninteresting or redundant documentation.
  This makes the package 4 times smaller (installed size divided
  by 15, from 33.1 MB to 2.2 MB on i386) (361885).
* Mon Jan 21 2008 sbrabec@suse.cz
- Updated to version 3.14.3:
  * HAL policy file is automatically installed on Linux systems to
    disable the hald-addon-hid-ups module which conflicts with
    apcupsd's control of USB UPSes. The file is automatically
    removed when apcupsd is uninstalled.
  * Add support for Nominal Power (aka Configured Active Power)
    reading.
  * Add units to NOMINV, NOMOUTV, and NOMBATTV stats.
  * Eliminate some gcc warnings.
  * Fix killpower and eeprom settings bug on USB modules introduced
    when INPUT reports were prioritized over FEATURE reports.
  * Fix bugs that could cause NIS-net driver to get stuck waiting
    for comms to be restored instead of shutting down.
- Fixed possible buffer overflow.
- Removed support for SuSE Linux <= 10.0.
* Mon Jan 14 2008 sbrabec@suse.cz
- Updated to version 3.14.2:
  * USB fix for BackUPS LCD series. This fix carries a risk of
    breaking other models, but test results are positive so far.
  * Fix linux-usb device detection bug when multiple hiddev nodes
    are present. Fixes Fedora#245864:
  * Fix SNMP port selection when using SNMP driver.
  * Add workaround for broken BackUPS Pro model that returns
    certain reports encoded in ASCII.
  * apcsmart: Wait 20 seconds before declaring COMMLOST.
  * Documentation updates: Fix up udev info for modern Linux
    distros.
  * Don't leak unnecessary descriptors to child when execing
    apccontrol.
  * Fix bug with multi-threaded net_open() calls.
  * Correct multimon.conf humidity monitoring. (Novell#199834)
  * Fix race between attach_ups() and detach_ups().
  * Remove dependency on libc++ (again).
* Thu Aug 23 2007 sbrabec@suse.cz
- Fixed multimon.conf comments for humidity measurement (#199834).
* Mon Jul 23 2007 ro@suse.de
- fix build
* Wed Jul  4 2007 sbrabec@suse.cz
- Updated to version 3.14.1:
  * PCNET driver supports remote shutdown request from UPS web
    interface
  * Fix potential NIS client lockup when server disappears.
  * Fix crash when displaying EEPROM values more than once.
  * Increase self-test timeout to 40 seconds to accomodate the
    RS 800.
  * Rewrite device opening logic to be more reliable.
  * Do not attempt to cancel shutdowns.
* Wed May 23 2007 ro@suse.de
- fix some rpmlint errors
* Wed Apr 11 2007 sbrabec@suse.cz
- Updated to version 3.14.0:
  * New stable release.
  * Bug fixes.
* Thu Nov 16 2006 mrueckert@suse.de
- added apcupsd-3.13.9_missing_netsnmp_include.patch:
  include for net-snmp-config.h was missing.
* Mon Nov  6 2006 ro@suse.de
- fix permissions for icon files
* Fri Oct 20 2006 sbrabec@suse.cz
- Updated to version 3.13.9:
  * Runtime configurable paths for apccontrol.
  * Ambient temperature is reported for USB UPSes with a AP9612
    SmartSlot card.
  * pcnet driver detects COMMLOST and SelfTest events.
  * pcnet driver supports killpower (turning off UPS output power).
  * Bug fixes.
* Wed Sep 20 2006 sbrabec@suse.cz
- Build correctly in older products.
* Wed Sep 20 2006 sbrabec@suse.cz
- Create /sbin/apcupsd-lite, working with unmounted /usr (#186606).
- Call killpower only if power is failing (#186606#6) (#187454).
- Minor fixes of previous update.
* Mon Sep 18 2006 sbrabec@suse.cz
- Updated to version 3.13.8:
  * GUI monitoring application, gapcmon.
  * Bug fixes.
* Tue Sep 12 2006 aj@suse.de
- Adjust BuildRequires.
* Mon Apr  3 2006 sbrabec@suse.cz
- Do not remove /etc/nologin, if changes are disabled (#161709).
* Sat Mar 25 2006 ro@suse.de
- remove second preun script
* Fri Mar 24 2006 sbrabec@suse.cz
- Removed fast incorrect shutdown script (#132478).
- Added README.SUSE.
- Integrated with powersave.
- Do not strip binaries.
- Simplified neededforbuild.
- Removed obsolete halt-setup.sh and clean halt.local.
- Scriptlet fixes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 ro@suse.de
- disable parallel build, seems to cause trouble
* Thu Jan 12 2006 sbrabec@suse.cz
- Updated to version 3.12.1.
* Fri Sep 30 2005 sbrabec@suse.cz
- Updated to version 3.10.18 (#116685).
* Tue Jul 12 2005 sbrabec@suse.cz
- Updated to version 3.10.17a.
- Moved binaries (linked against libraries in /usr) to /usr/sbin.
* Wed May  4 2005 sbrabec@suse.cz
- Removed START_APCUPSD from halt.local (#81281).
* Thu Jan  6 2005 sbrabec@suse.cz
- Updated to version 3.10.16.
* Tue Nov 30 2004 sbrabec@suse.cz
- Fixed OS misdetection (missing USB support, #48607).
  Patch from Andrea Arcangeli.
* Mon Aug 23 2004 sbrabec@suse.cz
- Updated to version 3.10.15.
* Mon Apr 19 2004 ro@suse.de
- Force-define HID_MAX_USAGES
- build using apache2
* Fri Mar 19 2004 sbrabec@suse.cz
- Removed *.orig files from documentation.
* Thu Feb  5 2004 sbrabec@suse.cz
- Updated to version 3.10.11.
* Mon Nov 10 2003 ro@suse.de
- use net-snmp instead of ucdsnmp
* Tue Sep 16 2003 kukuk@suse.de
- Remove setuid bit from apcupsd (else SuSEconfig will do it)
* Mon Sep  1 2003 sbrabec@suse.cz
- Removed tcpd.h (use systemwide instead).
* Mon Sep  1 2003 sbrabec@suse.cz
- Added "Should-Start: hotplug_usb" to init script.
- Fix and update hack of orphan fi in halt.local.
- Fixed pre and postinstall scripts.
- Really turned on and fixed SNMP support.
* Fri Aug 29 2003 kukuk@suse.de
- Add "Should-Start: serial" to init script [Bug #28353]
* Fri Aug 15 2003 sbrabec@suse.cz
- Updated to development version 3.10.6-05Aug03.
- Turned on all optional features.
* Mon Mar 10 2003 sbrabec@suse.cz
- Buffer overflow fixes.
- Name clash and error handling fixes.
* Wed Feb 12 2003 sbrabec@suse.cz
- Updated to version 3.8.6.
* Thu Aug 15 2002 mcihar@suse.cz
- added $remote_fs to Required-Start (should fix #17294)
* Thu Aug  1 2002 ro@suse.de
- adapted to /srv/www
- added prereqs
* Sat Jul 27 2002 adrian@suse.de
- fix build
* Mon Jan  7 2002 cihlar@suse.cz
- updated to version 3.8.5:
  * Battery Runtime Calibration in the apctest
    program
  * Resolved a crash caused by a lost TCP/IP
    connection
* Mon Dec 17 2001 cihlar@suse.cz
- updated to version 3.8.4-2:
  * bug fix release
* Mon Dec 10 2001 cihlar@suse.cz
- removed START_APCUPSD
* Thu Nov 29 2001 cihlar@suse.cz
- update to version 3.8.3:
  * updated manual
  * several bug fixes
  * added support for new hardware
- fixed permissions of halt-setup.sh
- fixed halt-setup.sh
- moved halt-setup.sh from %%postun to %%preun
* Tue Nov 27 2001 cihlar@suse.cz
- fixed variable names in init script [#12451]
* Thu Jul 26 2001 cihlar@suse.cz
- fixed call of suse_update_config
* Wed Jul 25 2001 cihlar@suse.cz
- update to 3.8.2
- added part with autoconf
- compile with --with-libwrap and --enable-pthreads
* Thu Apr 12 2001 cihlar@suse.cz
- fixed init script by new skeleton
* Mon Jan 15 2001 cihlar@suse.cz
- added apctest
* Wed Jan 10 2001 cihlar@suse.cz
- update to 3.8.1
- change to new init script mechanism
- fixed initialization of halt.local
- added BuildRoot
- clean up spec file
- bzipped sources
- added fillup of rc.config
* Mon Jun 19 2000 kasal@suse.de
- Updated to 3.7.2.  The package is still BETA, see "Todo" below.
* Sun Oct 10 1999 bk@suse.de
- new package, requested e.g by Andre Hedrick <andre@suse.com>
  Todo:
  - polish /sbin/init.d/apcupsd and add links to the rcX.d directories
  - add the proper START_APCUPSD= fillup for /etc/rc.config
  - add the changes for halt.sh in the suse subdir
